@@ -40,12 +40,13 @@ class Animation(QPropertyAnimation, ReprMixin):
         Animation.clsUid += 1
         self.uid = Animation.clsUid
         assert isinstance(graphicsObject, QObject)
-        QPropertyAnimation.__init__(self, graphicsObject, propName.encode(), parent)
+        _ = propName.encode()
+        QPropertyAnimation.__init__(self, graphicsObject, _, parent)
         QPropertyAnimation.setEndValue(self, endValue)
         assert Internal.Preferences
         duration = Internal.Preferences.animationDuration()
         self.setDuration(duration)
-        self.setEasingCurve(QEasingCurve.InOutQuad)
+        self.setEasingCurve(QEasingCurve.Type.InOutQuad)
         graphicsObject.queuedAnimations.append(self)
         Animation.nextAnimations.append(self)
         if self.debug:
@@ -85,18 +86,21 @@ class Animation(QPropertyAnimation, ReprMixin):
         """
         if not isAlive(self):
             return 'notAlive'
-        return bytes(self.propertyName()).decode()
+        _ = self.propertyName()
+        return bytes(_).decode()
 
     def formatValue(self, value:PropertyType) ->str:
         """string format the wanted value from qvariant"""
         pName = self.pName()
         if pName == 'pos':
-            assert isinstance(value, QPointF)
-            return f'{value.x():.0f}/{value.y():.0f}'
+            _ = cast(QPointF, value)
+            return f'{_.x():.0f}/{_.y():.0f}'
         if pName == 'rotation':
-            return f'{int(value)}'
+            _ = cast(int, value)
+            return str(_)
         if pName == 'scale':
-            return f'{value:.2f}'
+            _ = cast(float, value)
+            return f'{_:.2f}'
         return f'formatValue: unexpected {pName}={value}'
 
     def __str__(self) ->str:
